openmensa library

A library which provides simple access to OpenMensa's API services for Dart.

Classes

Canteen
Models a canteen containing information about its metadata.
Day
Models a day containing information about whether a canteen is closed or not.
DayMenu
Models a day menu containing information about a day and the daily available meals.
Meal
Models a meal containing information about its metadata.
OpenMensaAPI
Provides simple access to OpenMensa's API services.

Extensions

CanteenPatterns on Canteen
Adds pattern-matching-related methods to Canteen.
DayMenuPatterns on DayMenu
Adds pattern-matching-related methods to DayMenu.
DayPatterns on Day
Adds pattern-matching-related methods to Day.
MealPatterns on Meal
Adds pattern-matching-related methods to Meal.
OpenMensaDate on DateTime
Extension to offer methods for better handling with the OpenMensa API.

Constants

apiBasePath → const String
OpenMensa's API base endpoint.
apiBaseUrl → const String
OpenMensa's API base URL.
httpOkay → const int
The HTTP status code for OK messages.

Functions

parseList<T>(String source, JsonParser<T> parser) List<T>
Parses a list from the given JSON string using the given parser.
parseObject<T>(String source, JsonParser<T> parser) → T?
Parses an object from the given JSON string using the given parser.

Typedefs

JsonParser<T> = T Function(Map<String, dynamic> json)
The type for a JSON to object parser.